//+------------------------------------------------------------------+
//|                                                #activeorders.mq4 |
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright ""
#property link      ""
#property indicator_chart_window

extern string font_name   =  "Arial Bold";   // print the labels
extern int    font_size  =  9;               // size of the font list items 
extern int    position_corner =  2;          // angle of anchor text labels 

int    labs_xdist  =   5;            // rasctoyanie X on the window border 
int    labs_ydist  =  -7;            // distance Y from the window border 
int    labs_space  =  14;            // Y spacing between labels 
int    labs_max    =  15;            // maximum number of labels

#define MAX_ARRAY 50

extern color  profit_colour  =  Lime;  // color for profit positions 
extern color  loss_colour    =  Red;     // color for the loss-making positions
extern color  line_break_colour  =  White;

extern string Selecting_True_Below_Will = "Display All Open Orders (Every Pair)";
extern string Selecting_False_Below_Will = "Display Open Orders For This Pair";
extern bool   show_all_open_orders = true;
extern bool   show_profit_values = true;

//--------------------------------------------------------------------------+
void init(){

   for(int i = 1; i <= labs_max; i++){             	// create 15 text boxes to display
      ObjectCreate("lab"+i, OBJ_LABEL, 0, 0, 0);
      ObjectSet("lab"+i, OBJPROP_CORNER, position_corner);
      ObjectSet("lab"+i, OBJPROP_XDISTANCE, labs_xdist);
      ObjectSet("lab"+i, OBJPROP_YDISTANCE, i * labs_space + labs_ydist);
      ObjectSetText("lab"+i, "",0,"",0);
   }
   
   if( labs_max > MAX_ARRAY-1 )  // our array size is MAX_ARRAY elements in indicate_orders
       labs_max = MAX_ARRAY-1 ;
}
//--------------------------------------------------------------------------+
void deinit(){

   for(int i = 1; i <= labs_max; i++)     	// remove all text fields 
      ObjectDelete("lab"+i);
}
//--------------------------------------------------------------------------+
void indicate_orders(){
   int nb = 0, ns = 0, lab = 1, lbn = 0;
   int buys_profit = 0, sells_profit = 0;
   double buys_volume = 0.0, sells_volume = 0.0, buysym = 0.0;
   double buys_list[MAX_ARRAY][3];
   double sells_list[MAX_ARRAY][3];
   string sellsymbol[MAX_ARRAY];
   string buysymbol[MAX_ARRAY]; 
   string res;
  
  // Count of all open positions at this time of the current
   for( int i = 0; i < OrdersTotal(); i++){
      if( !OrderSelect(i, SELECT_BY_POS, MODE_TRADES) )
         continue;
   
      if( !show_all_open_orders ){
         if( OrderSymbol() != Symbol() )
            continue;
      }
    
      if( OrderType() == OP_BUY ){
         buysymbol[nb] = OrderSymbol(); 
         buys_list[nb][1] = OrderProfit();
         buys_list[nb][2] = ( OrderProfit() - OrderCommission() ) / OrderLots() / MarketInfo( OrderSymbol(), MODE_TICKVALUE );
         buys_profit += buys_list[nb][1];
         buys_volume += buys_list[nb][2];
         nb++;
      }
    
      if( OrderType() == OP_SELL ){
         sellsymbol[ns] = OrderSymbol();
         sells_list[ns][1] = OrderProfit();
         sells_list[ns][2] = ( OrderProfit() - OrderCommission() ) / OrderLots() / MarketInfo( OrderSymbol(), MODE_TICKVALUE );
         sells_profit += sells_list[ns][1];
         sells_volume += sells_list[ns][2];
         ns++;
      }
   }

   // Display all open positions 
   if(nb > 0){
      if(buys_profit > 0)
         lab++;
      lbn = lab;
      
      for(i = 0; i < nb; i++){
         lab = lbn + i;
         if(buys_list[i][1] > 0){
            res = "Buy " + buysymbol[i]+  "  Pips  +" + DoubleToStr(buys_list[i][2]/10, 1);
            if( show_profit_values )   
               res = res + "  Profit +" + DoubleToStr(buys_list[i][1], 2);
         
            ObjectSetText("lab"+lab, res, font_size, font_name, profit_colour);
         }
         else{
            res = "Buy " +buysymbol[i]+  "  Pips  " + DoubleToStr(buys_list[i][2]/10, 1);
            if( show_profit_values )
               res = res + "  Profit  " + DoubleToStr(buys_list[i][1], 2);
            
            ObjectSetText("lab"+lab, res, font_size, font_name, loss_colour);    
         }
      
         lab++;
         if( !show_profit_values )    
            ObjectSetText("lab"+lab, "-----------------------------------", 9, "Arial", line_break_colour);
         else
            ObjectSetText("lab"+lab, "------------------------------------------------------", 9, "Arial", line_break_colour);  
      }
   }
  
   if(ns > 0){
      if(nb > 0)
         lab++;
      lbn = lab;

      for(i = 0; i < ns; i++){
         lab = lbn + i;
         if(sells_list[i][1] > 0){ 
            res = "Sell " +sellsymbol[i]+  "  Pips +" + DoubleToStr(sells_list[i][2]/10, 1);
            if( show_profit_values )
               res = res + "  Profit +" + DoubleToStr(sells_list[i][1], 2);

            ObjectSetText("lab"+lab, res, font_size, font_name, profit_colour);
         }
         else{
            res = "Sell " +sellsymbol[i]+  "  Pips  " + DoubleToStr(sells_list[i][2]/10, 1);
            if( show_profit_values )
               res = res + "  Profit  " + DoubleToStr(sells_list[i][1], 2);

            ObjectSetText("lab"+lab, res, font_size, font_name, loss_colour);
         }
      }
   }
  
   for(i = lab+1; i <= labs_max; i++)  // clear all the rest of the labels
      ObjectSetText("lab"+i, "");
}
//--------------------------------------------------------------------------+
void start(){
  indicate_orders();

}